@@ -520,6 +520,20 @@ public:
             .add_coerced_subscriber(
                 std::bind(&ubx_xcvr::set_sync_delay, this, true, std::placeholders::_1))
             .set(0);
+        get_tx_subtree()
+            ->create<bool>("calibrate_vco_map")
+            .add_coerced_subscriber(
+                std::bind(&ubx_xcvr::calibrate_vco_maps, this, TX_DIRECTION));
+        get_tx_subtree()
+            ->create<std::map<uint8_t, uhd::range_t>>("LO1/vco_map")
+            .add_coerced_subscriber(std::bind(
+                &ubx_xcvr::set_vco_map, this, TX_DIRECTION, 1, std::placeholders::_1))
+            .set_publisher(std::bind(&ubx_xcvr::get_vco_map, this, TX_DIRECTION, 1));
+        get_tx_subtree()
+            ->create<std::map<uint8_t, uhd::range_t>>("LO2/vco_map")
+            .add_coerced_subscriber(std::bind(
+                &ubx_xcvr::set_vco_map, this, TX_DIRECTION, 2, std::placeholders::_1))
+            .set_publisher(std::bind(&ubx_xcvr::get_vco_map, this, TX_DIRECTION, 2));
 
         ////////////////////////////////////////////////////////////////////
         // Register RX properties
@@ -558,6 +572,20 @@ public:
             .add_coerced_subscriber(
                 std::bind(&ubx_xcvr::set_sync_delay, this, false, std::placeholders::_1))
             .set(0);
+        get_rx_subtree()
+            ->create<bool>("calibrate_vco_map")
+            .add_coerced_subscriber(
+                std::bind(&ubx_xcvr::calibrate_vco_maps, this, RX_DIRECTION));
+        get_rx_subtree()
+            ->create<std::map<uint8_t, uhd::range_t>>("LO1/vco_map")
+            .add_coerced_subscriber(std::bind(
+                &ubx_xcvr::set_vco_map, this, RX_DIRECTION, 1, std::placeholders::_1))
+            .set_publisher(std::bind(&ubx_xcvr::get_vco_map, this, RX_DIRECTION, 1));
+        get_rx_subtree()
+            ->create<std::map<uint8_t, uhd::range_t>>("LO2/vco_map")
+            .add_coerced_subscriber(std::bind(
+                &ubx_xcvr::set_vco_map, this, RX_DIRECTION, 2, std::placeholders::_1))
+            .set_publisher(std::bind(&ubx_xcvr::get_vco_map, this, RX_DIRECTION, 2));
     }
 
     ~ubx_xcvr(void) override
@@ -800,9 +828,9 @@ private:
             // Force on TX PA for boards with high isolation or if the user sets the TDD
             // mode
             set_cpld_field(TXDRV_FORCEON,
-                (_power_mode == POWERSAVE
-                        ? 0
-                        : _high_isolation or _xcvr_mode == TDD ? 1 : 0));
+                (_power_mode == POWERSAVE                  ? 0
+                    : _high_isolation or _xcvr_mode == TDD ? 1
+                                                           : 0));
         } else {
             set_gpio_field(RX_ANT, 1);
             set_cpld_field(
@@ -1048,7 +1076,7 @@ private:
         }
 
         // Work with frequencies
-        if (freq < 100 * fMHz) {
+        if (freq < 42 * fMHz) {
             set_cpld_field(SEL_LNA1, 0);
             set_cpld_field(SEL_LNA2, 1);
             set_cpld_field(RXLO1_FSEL3, 1);
@@ -1056,16 +1084,20 @@ private:
             set_cpld_field(RXLO1_FSEL1, 0);
             set_cpld_field(RXLB_SEL, 1);
             set_cpld_field(RXHB_SEL, 0);
-            // Set LO1 to IF of 2380 MHz (2440 MHz filter center minus 60 MHz offset to
-            // minimize LO leakage)
+
+            // The filter on the IF has a center of 2440 MHz and an 84 MHz bandwidth.
+            // For frequencies under 42 MHz, the LO for the IF will be in the filter
+            // bandwidth.  Shift the IF to move the LO to the edge of the filter bandwidth
+            // to reduce LO leakage.
+            double if_freq = 2398 * fMHz + freq;
             freq_lo1 =
-                _rxlo1->set_frequency(2380 * fMHz, ref_freq, target_pfd_freq, is_int_n);
+                _rxlo1->set_frequency(if_freq, ref_freq, target_pfd_freq, is_int_n);
             _rxlo1->set_output_power(max287x_iface::OUTPUT_POWER_5DBM);
             // Set LO2 to IF minus desired frequency
             freq_lo2 = _rxlo2->set_frequency(
                 freq_lo1 - freq, ref_freq, target_pfd_freq, is_int_n);
             _rxlo2->set_output_power(max287x_iface::OUTPUT_POWER_2DBM);
-        } else if ((freq >= 100 * fMHz) && (freq < 500 * fMHz)) {
+        } else if ((freq >= 42 * fMHz) && (freq < 500 * fMHz)) {
             set_cpld_field(SEL_LNA1, 0);
             set_cpld_field(SEL_LNA2, 1);
             set_cpld_field(RXLO1_FSEL3, 1);
@@ -1298,6 +1330,96 @@ private:
         }
     }
 
+    void calibrate_vco_maps(uhd::direction_t dir)
+    {
+        if (dir == TX_DIRECTION) {
+            double orig_freq = _tx_freq;
+            double ref_freq  = _iface->get_clock_rate(dboard_iface::UNIT_TX);
+
+            // Set to high band frequency (so lock detect will be LO1 only)
+            set_tx_freq(6000 * fMHz);
+            // Calibrate LO1
+            _txlo1->calibrate_vco_map(
+                [this]() { return this->get_gpio_field(TX_LO_LOCKED) != 0; },
+                ref_freq,
+                _tx_target_pfd_freq);
+            // Set to low band frequency (so LO1 will be fixed and lock detect will be LO1
+            // & LO2)
+            set_tx_freq(400 * fMHz);
+            // Calibrate LO2
+            _txlo2->calibrate_vco_map(
+                [this]() { return this->get_gpio_field(TX_LO_LOCKED) != 0; },
+                ref_freq,
+                _tx_target_pfd_freq);
+            // Restore to original frequency
+            set_tx_freq(orig_freq);
+        } else {
+            double orig_freq = _rx_freq;
+            double ref_freq  = _iface->get_clock_rate(dboard_iface::UNIT_RX);
+
+            // Set to high band frequency (so lock detect will be LO1 only)
+            set_rx_freq(6000 * fMHz);
+            // Calibrate LO1
+            _rxlo1->calibrate_vco_map(
+                [this]() { return this->get_gpio_field(RX_LO_LOCKED) != 0; },
+                ref_freq,
+                _rx_target_pfd_freq);
+            // Set to low band frequency (so LO1 will be fixed and lock detect will be LO1
+            // & LO2)
+            set_rx_freq(400 * fMHz);
+            // Calibrate LO2
+            _rxlo2->calibrate_vco_map(
+                [this]() { return this->get_gpio_field(RX_LO_LOCKED) != 0; },
+                ref_freq,
+                _rx_target_pfd_freq);
+            // Restore to original frequency
+            set_rx_freq(orig_freq);
+        }
+    }
+
+    std::map<uint8_t, uhd::range_t> get_vco_map(uhd::direction_t dir, size_t which)
+    {
+        if (dir == TX_DIRECTION) {
+            if (which == 1) {
+                return _txlo1->get_vco_map();
+            } else if (which == 2) {
+                return _txlo2->get_vco_map();
+            } else {
+                UHD_THROW_INVALID_CODE_PATH();
+            }
+        } else {
+            if (which == 1) {
+                return _rxlo1->get_vco_map();
+            } else if (which == 2) {
+                return _rxlo2->get_vco_map();
+            } else {
+                UHD_THROW_INVALID_CODE_PATH();
+            }
+        }
+    }
+
+    void set_vco_map(
+        uhd::direction_t dir, size_t which, const std::map<uint8_t, uhd::range_t>& map)
+    {
+        if (dir == TX_DIRECTION) {
+            if (which == 1) {
+                _txlo1->set_vco_map(map);
+            } else if (which == 2) {
+                _txlo2->set_vco_map(map);
+            } else {
+                UHD_THROW_INVALID_CODE_PATH();
+            }
+        } else {
+            if (which == 1) {
+                _rxlo1->set_vco_map(map);
+            } else if (which == 2) {
+                _rxlo2->set_vco_map(map);
+            } else {
+                UHD_THROW_INVALID_CODE_PATH();
+            }
+        }
+    }
+
     /***********************************************************************
      * Variables
      **********************************************************************/
