@@ -5,8 +5,8 @@
 //
 
 #include <uhdlib/utils/isatty.hpp>
-#include <cstdio>
 #include <boost/test/unit_test.hpp>
+#include <cstdio>
 #include <iostream>
 
 BOOST_AUTO_TEST_CASE(test_isatty)
@@ -18,7 +18,8 @@ BOOST_AUTO_TEST_CASE(test_isatty)
     } else {
         std::cout << "stderr is not a TTY" << std::endl;
     }
-    auto tmp_file = std::unique_ptr<std::FILE, decltype(&std::fclose)>(std::tmpfile(), &std::fclose);
+    auto tmp_file =
+        std::unique_ptr<std::FILE, decltype(&std::fclose)>(std::tmpfile(), &std::fclose);
 #ifdef UHD_PLATFORM_WIN32
     BOOST_REQUIRE(!uhd::is_a_tty(_fileno(tmp_file.get())));
 #elif _POSIX_C_SOURCE >= _200112L
